SQLModel
========
Example factories for models based on `SQLModel <https://sqlmodel.tiangolo.com>`_.

Installation
------------
.. code-block:: sh

    pip install -r requirements.in

Testing
-------
.. code-block:: sh

    pytest

or

.. code-block:: sh

    python manage.py test
